package com.jiuqi.grid;

import java.io.Serializable;

/* loaded from: com_jiuqi_grid.jar:com/jiuqi/grid/CurrencyCellProperty.class */
public final class CurrencyCellProperty extends NumberCellProperty implements CurrencyCellPropertyIntf, CellDataProcessorIntf, Serializable {
    public static final String[] CURRENCY_UNIT_NAMES = {"", "CNY", "USD", "EUR", "JPY", "HKD", "GBP", "CHF", "SUR", "CAD"};
    public static final String[] CURRENCY_UNIT_TITLES = {"", "人民币元", "美元", "欧元", "日圆", "港元", "英镑", "瑞士法郎", "俄罗斯卢布", "加拿大元"};
    public static final String[] CURRENCY_UNIT_SIGNS = {"", "￥", "＄", "EUR", "J.￥", "HK＄", "￡", "SF.", "Rbs.", "Can.＄"};

    public CurrencyCellProperty(GridCell cell) {
        this(new CellDataProperty(cell));
    }

    public CurrencyCellProperty(CellDataPropertyIntf dataProperty) {
        super(dataProperty);
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public int getUnitIndex() {
        int dataFormat = this.cellDataProperty.getDataFormat();
        return dataFormat & 15;
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public void setUnitIndex(int value) {
        if (value < 0 || value >= 10) {
            throw new IllegalArgumentException("货币符号被错误设置,只能在0-9之间!");
        }
        this.cellDataProperty.setDataFormat((byte) value);
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public int getUnitShowType() {
        return (this.cellDataProperty.getDataProperty() & 768) >> 8;
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public void setUnitShowType(int value) {
        if (value < 0 || value > 3) {
            throw new IllegalArgumentException("显示类型被错误设置,应该被设置到0-3之间!");
        }
        this.cellDataProperty.setDataProPerty((short) ((this.cellDataProperty.getDataProperty() & (-769)) | ((value & 3) << 8)));
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public String getUnitTitle() {
        return CURRENCY_UNIT_TITLES[getUnitIndex()];
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public void setUnitTitle(String value) {
        int i = 0;
        boolean found = false;
        while (true) {
            if (0 != 0) {
                break;
            }
            if (value.equals(CURRENCY_UNIT_TITLES[i])) {
                found = true;
                break;
            }
            i++;
        }
        if (found) {
            setUnitIndex(i);
            return;
        }
        throw new IllegalArgumentException("没有这样的货币单位!");
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public boolean getShowCurrencyBox() {
        return this.cellDataProperty.getDataType() == 3 && (this.cellDataProperty.getDataProperty() & 1024) != 0;
    }

    @Override // com.jiuqi.grid.CurrencyCellPropertyIntf
    public void setShowCurrencyBox(boolean value) {
        if (this.cellDataProperty.getDataType() == 3) {
            if (value) {
                this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() | 1024));
            } else {
                this.cellDataProperty.setDataProPerty((short) (this.cellDataProperty.getDataProperty() & (-1025)));
            }
        }
    }

    public String getUnitString() {
        return CURRENCY_UNIT_SIGNS[getUnitIndex()];
    }

    @Override // com.jiuqi.grid.NumberCellProperty, com.jiuqi.grid.CellDataProcessorIntf
    public String getShowText(String storeText) {
        String showText = super.getShowText(storeText);
        int unitIndex = getUnitIndex();
        if (unitIndex >= 0) {
            int unitShowType = getUnitShowType();
            switch (unitShowType) {
                case 0:
                    showText = String.valueOf(CURRENCY_UNIT_SIGNS[unitIndex]) + " " + showText;
                    break;
                case 1:
                    showText = String.valueOf(CURRENCY_UNIT_NAMES[unitIndex]) + " " + showText;
                    break;
                case 2:
                    showText = String.valueOf(showText) + " " + CURRENCY_UNIT_NAMES[unitIndex];
                    break;
                case 3:
                    showText = String.valueOf(CURRENCY_UNIT_TITLES[unitIndex]) + " " + showText;
                    break;
            }
        }
        return showText;
    }

    @Override // com.jiuqi.grid.NumberCellProperty, com.jiuqi.grid.CellDataProcessorIntf
    public String parseShowText(String showText) {
        String number;
        int unitIndex = getUnitIndex();
        int unitShowType = getUnitShowType();
        switch (unitShowType) {
            case 0:
                String unitAdd = CURRENCY_UNIT_SIGNS[unitIndex];
                if (showText.startsWith(unitAdd)) {
                    number = showText.substring(unitAdd.length());
                    break;
                } else {
                    throw new IllegalArgumentException("开头的货币符号和定义的货币符号不符！");
                }
            case 1:
                String unitAdd2 = CURRENCY_UNIT_NAMES[unitIndex];
                if (showText.startsWith(unitAdd2)) {
                    number = showText.substring(unitAdd2.length());
                    break;
                } else {
                    throw new IllegalArgumentException("开头的货币英文缩写和定义的货币符号不符！");
                }
            case 2:
                String unitAdd3 = CURRENCY_UNIT_NAMES[unitIndex];
                if (showText.endsWith(unitAdd3)) {
                    number = showText.substring(0, showText.length() - unitAdd3.length());
                    break;
                } else {
                    throw new IllegalArgumentException("尾部的货币英文缩写和定义的货币符号不符！");
                }
            case 3:
                String unitAdd4 = CURRENCY_UNIT_TITLES[unitIndex];
                if (showText.endsWith(unitAdd4)) {
                    number = showText.substring(0, showText.length() - unitAdd4.length());
                    break;
                } else {
                    throw new IllegalArgumentException("尾部的货币名称和定义的货币符号不符！");
                }
            default:
                number = showText;
                break;
        }
        return super.parseShowText(number);
    }
}
